==> haskell-strict-0.5.1-6-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict
version:              0.5.1
visibility:           public
id:                   strict-0.5.1-DOtb9Mi0AldCt12sYxVGp0
key:                  strict-0.5.1-DOtb9Mi0AldCt12sYxVGp0
license:              BSD-3-Clause
copyright:
    (c) 2006-2008 by Roman Leshchinskiy
    (c) 2013-2014 by Simon Meier

maintainer:
    Don Stewart <dons@galois.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>,
    Oleg Grenrus <oleg.grenrus@iki.fi>,
    Simon Meier <iridcode@gmail.com>,
    Ximin Luo <infinity0@pwned.gg>

author:
    Roman Leshchinskiy <rl@cse.unsw.edu.au>
    Simon Meier <iridcode@gmail.com>

homepage:             https://github.com/haskell-strict/strict
synopsis:             Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO operations.

    It is common knowledge that lazy datastructures can lead to space-leaks.
    This problem is particularly prominent, when using lazy datastructures to
    store the state of a long-running application in memory. One common
    solution to this problem is to use @seq@ and its variants in every piece of
    code that updates your state. However a much easier solution is to use
    fully strict types to store such state values. By \"fully strict types\" we
    mean types for whose values it holds that, if they are in weak-head normal
    form, then they are also in normal form. Intuitively, this means that
    values of fully strict types cannot contain unevaluated thunks.

    To define a fully strict datatype, one typically uses the following recipe.

    1. Make all fields of every constructor strict; i.e., add a bang to
    all fields.

    2. Use only strict types for the fields of the constructors.

    The second requirement is problematic as it rules out the use of
    the standard Haskell '\''Maybe'\'', '\''Either'\'', and pair types. This library
    solves this problem by providing strict variants of these types and their
    corresponding standard support functions and type-class instances.

    Note that this library does currently not provide fully strict lists.
    They can be added if they are really required. However, in many cases one
    probably wants to use unboxed or strict boxed vectors from the '\''vector'\''
    library (<http://hackage.haskell.org/package/vector>) instead of strict
    lists.  Moreover, instead of @String@s one probably wants to use strict
    @Text@ values from the @text@ library
    (<http://hackage.haskell.org/package/text>).

    This library comes with batteries included; i.e., mirror functions and
    instances of the lazy versions in @base@. It also includes instances for
    type-classes from the @deepseq@, @binary@, and @hashable@ packages.

category:             Data, System
abi:                  f988e704f45f463c2e9fd86420edf6dc
exposed:              True
exposed-modules:
    Data.Strict Data.Strict.Classes Data.Strict.Either
    Data.Strict.Maybe Data.Strict.These Data.Strict.Tuple
    System.IO.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict
hs-libraries:         HSstrict-0.5.1-DOtb9Mi0AldCt12sYxVGp0
depends:
    assoc-1.1.1-ECHUyXuI4DU7saXDIs2gf3 base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7 text-2.0.2
    these-1.2.1-GRo353fncrv9e3TrAWHPmf transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html:         /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-0.5.1-21.3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict
version:              0.5.1
visibility:           public
id:                   strict-0.5.1-2qreVmQS6xqA7wSvTCBI0d
key:                  strict-0.5.1-2qreVmQS6xqA7wSvTCBI0d
license:              BSD-3-Clause
copyright:
    (c) 2006-2008 by Roman Leshchinskiy
    (c) 2013-2014 by Simon Meier

maintainer:
    Don Stewart <dons@galois.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>,
    Oleg Grenrus <oleg.grenrus@iki.fi>,
    Simon Meier <iridcode@gmail.com>,
    Ximin Luo <infinity0@pwned.gg>

author:
    Roman Leshchinskiy <rl@cse.unsw.edu.au>
    Simon Meier <iridcode@gmail.com>

homepage:             https://github.com/haskell-strict/strict
synopsis:             Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO operations.

    It is common knowledge that lazy datastructures can lead to space-leaks.
    This problem is particularly prominent, when using lazy datastructures to
    store the state of a long-running application in memory. One common
    solution to this problem is to use @seq@ and its variants in every piece of
    code that updates your state. However a much easier solution is to use
    fully strict types to store such state values. By \"fully strict types\" we
    mean types for whose values it holds that, if they are in weak-head normal
    form, then they are also in normal form. Intuitively, this means that
    values of fully strict types cannot contain unevaluated thunks.

    To define a fully strict datatype, one typically uses the following recipe.

    1. Make all fields of every constructor strict; i.e., add a bang to
    all fields.

    2. Use only strict types for the fields of the constructors.

    The second requirement is problematic as it rules out the use of
    the standard Haskell '\''Maybe'\'', '\''Either'\'', and pair types. This library
    solves this problem by providing strict variants of these types and their
    corresponding standard support functions and type-class instances.

    Note that this library does currently not provide fully strict lists.
    They can be added if they are really required. However, in many cases one
    probably wants to use unboxed or strict boxed vectors from the '\''vector'\''
    library (<http://hackage.haskell.org/package/vector>) instead of strict
    lists.  Moreover, instead of @String@s one probably wants to use strict
    @Text@ values from the @text@ library
    (<http://hackage.haskell.org/package/text>).

    This library comes with batteries included; i.e., mirror functions and
    instances of the lazy versions in @base@. It also includes instances for
    type-classes from the @deepseq@, @binary@, and @hashable@ packages.

category:             Data, System
abi:                  7413577b5323211e348d7f9ebb138264
exposed:              True
exposed-modules:
    Data.Strict Data.Strict.Classes Data.Strict.Either
    Data.Strict.Maybe Data.Strict.These Data.Strict.Tuple
    System.IO.Strict

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/strict-0.5.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/strict-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/strict-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict
hs-libraries:         HSstrict-0.5.1-2qreVmQS6xqA7wSvTCBI0d
depends:
    assoc-1.1.1-LUcbvYkR3B88O6CpQIBVE6 base-4.18.3.0 binary-0.8.9.1
    bytestring-0.11.5.4 deepseq-1.4.8.1 ghc-prim-0.10.0
    hashable-1.4.7.0-17jkMnZLQLs4o2IKp4JpPo text-2.0.2
    these-1.2.1-8yONRQ8fpJ8Up4VI4BEBS transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html:         /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
